[nautilus-actions/file-manager-actions] NactMainTab class is renamed to FMAMainTab



commit 0339d41a51ccdcfe363eaa4bed4e0a0b2e0d1593
Author: Pierre Wieser <pwieser trychlos org>
Date:   Tue Sep 8 20:06:58 2015 +0200

    NactMainTab class is renamed to FMAMainTab

 src/ui/Makefile.am                         |    4 ++--
 src/ui/fma-iaction-tab.c                   |    6 +++---
 src/ui/fma-ibasenames-tab.c                |    6 +++---
 src/ui/fma-icapabilities-tab.c             |    6 +++---
 src/ui/fma-icommand-tab.c                  |    6 +++---
 src/ui/fma-ienvironment-tab.c              |    6 +++---
 src/ui/fma-iexecution-tab.c                |    6 +++---
 src/ui/fma-ifolders-tab.c                  |    6 +++---
 src/ui/fma-imimetypes-tab.c                |    6 +++---
 src/ui/fma-iproperties-tab.c               |    6 +++---
 src/ui/fma-ischemes-tab.c                  |    6 +++---
 src/ui/{nact-main-tab.c => fma-main-tab.c} |   18 +++++++++---------
 src/ui/{nact-main-tab.h => fma-main-tab.h} |   16 ++++++++--------
 src/ui/nact-main-window.c                  |    2 +-
 src/ui/nact-match-list.c                   |    4 ++--
 src/ui/nact-menu-edit.c                    |    2 +-
 src/ui/nact-menu-file.c                    |    2 +-
 src/ui/nact-schemes-list.c                 |    2 +-
 src/ui/nact-tree-model.c                   |    2 +-
 19 files changed, 56 insertions(+), 56 deletions(-)
---
diff --git a/src/ui/Makefile.am b/src/ui/Makefile.am
index fd23594..6289423 100644
--- a/src/ui/Makefile.am
+++ b/src/ui/Makefile.am
@@ -107,8 +107,8 @@ fma_config_tool_SOURCES = \
        fma-iproperties-tab.h                                                           \
        fma-ischemes-tab.c                                                                      \
        fma-ischemes-tab.h                                                                      \
-       nact-main-tab.c                                                                         \
-       nact-main-tab.h                                                                         \
+       fma-main-tab.c                                                                          \
+       fma-main-tab.h                                                                          \
        nact-main-window.c                                                                      \
        nact-main-window.h                                                                      \
        nact-main-window-def.h                                                          \
diff --git a/src/ui/fma-iaction-tab.c b/src/ui/fma-iaction-tab.c
index 6a0a54f..2c14303 100644
--- a/src/ui/fma-iaction-tab.c
+++ b/src/ui/fma-iaction-tab.c
@@ -43,7 +43,7 @@
 #include "fma-application.h"
 #include "nact-statusbar.h"
 #include "base-gtk-utils.h"
-#include "nact-main-tab.h"
+#include "fma-main-tab.h"
 #include "nact-main-window.h"
 #include "fma-iaction-tab.h"
 #include "fma-icon-chooser.h"
@@ -181,7 +181,7 @@ fma_iaction_tab_init( FMAIActionTab *instance )
        g_debug( "%s: instance=%p (%s)",
                        thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ));
 
-       nact_main_tab_init( NACT_MAIN_WINDOW( instance ), TAB_ACTION );
+       fma_main_tab_init( NACT_MAIN_WINDOW( instance ), TAB_ACTION );
        initialize_gtk( instance );
        initialize_window( instance );
 
@@ -356,7 +356,7 @@ on_tree_selection_changed( NactTreeView *tview, GList *selected_items, FMAIActio
                        instance, G_OBJECT_TYPE_NAME( instance ));
 
        enable_tab = ( count_selected == 1 );
-       nact_main_tab_enable_page( NACT_MAIN_WINDOW( instance ), TAB_ACTION, enable_tab );
+       fma_main_tab_enable_page( NACT_MAIN_WINDOW( instance ), TAB_ACTION, enable_tab );
 
        data = get_iaction_data( instance );
        data->on_selection_change = TRUE;
diff --git a/src/ui/fma-ibasenames-tab.c b/src/ui/fma-ibasenames-tab.c
index f5c1633..45319e2 100644
--- a/src/ui/fma-ibasenames-tab.c
+++ b/src/ui/fma-ibasenames-tab.c
@@ -39,7 +39,7 @@
 
 #include "base-gtk-utils.h"
 #include "fma-ibasenames-tab.h"
-#include "nact-main-tab.h"
+#include "fma-main-tab.h"
 #include "nact-main-window.h"
 #include "nact-match-list.h"
 
@@ -164,7 +164,7 @@ fma_ibasenames_tab_init( FMAIBasenamesTab *instance )
                        thisfn,
                        ( void * ) instance, G_OBJECT_TYPE_NAME( instance ));
 
-       nact_main_tab_init( NACT_MAIN_WINDOW( instance ), TAB_BASENAMES );
+       fma_main_tab_init( NACT_MAIN_WINDOW( instance ), TAB_BASENAMES );
        initialize_gtk( instance );
        initialize_window( instance );
 
@@ -249,7 +249,7 @@ on_tree_selection_changed( NactTreeView *tview, GList *selected_items, FMAIBasen
                        NULL );
 
        enable_tab = ( context != NULL );
-       nact_main_tab_enable_page( NACT_MAIN_WINDOW( instance ), TAB_BASENAMES, enable_tab );
+       fma_main_tab_enable_page( NACT_MAIN_WINDOW( instance ), TAB_BASENAMES, enable_tab );
 
        data = get_ibasenames_data( FMA_IBASENAMES_TAB( instance ));
        data->on_selection_change = TRUE;
diff --git a/src/ui/fma-icapabilities-tab.c b/src/ui/fma-icapabilities-tab.c
index c13cf98..619da71 100644
--- a/src/ui/fma-icapabilities-tab.c
+++ b/src/ui/fma-icapabilities-tab.c
@@ -38,7 +38,7 @@
 
 #include "core/fma-gtk-utils.h"
 
-#include "nact-main-tab.h"
+#include "fma-main-tab.h"
 #include "nact-main-window.h"
 #include "nact-match-list.h"
 #include "fma-add-capability-dialog.h"
@@ -152,7 +152,7 @@ fma_icapabilities_tab_init( FMAICapabilitiesTab *instance )
                        thisfn,
                        ( void * ) instance, G_OBJECT_TYPE_NAME( instance ));
 
-       nact_main_tab_init( NACT_MAIN_WINDOW( instance ), TAB_CAPABILITIES );
+       fma_main_tab_init( NACT_MAIN_WINDOW( instance ), TAB_CAPABILITIES );
        initialize_gtk( instance );
        initialize_window( instance );
 
@@ -215,7 +215,7 @@ on_tree_selection_changed( NactTreeView *tview, GList *selected_items, FMAICapab
                        NULL );
 
        enable_tab = ( context != NULL );
-       nact_main_tab_enable_page( NACT_MAIN_WINDOW( instance ), TAB_CAPABILITIES, enable_tab );
+       fma_main_tab_enable_page( NACT_MAIN_WINDOW( instance ), TAB_CAPABILITIES, enable_tab );
 }
 
 static void
diff --git a/src/ui/fma-icommand-tab.c b/src/ui/fma-icommand-tab.c
index e12b5d2..4733ead 100644
--- a/src/ui/fma-icommand-tab.c
+++ b/src/ui/fma-icommand-tab.c
@@ -44,7 +44,7 @@
 #include "fma-application.h"
 #include "nact-statusbar.h"
 #include "base-gtk-utils.h"
-#include "nact-main-tab.h"
+#include "fma-main-tab.h"
 #include "nact-main-window.h"
 #include "fma-icommand-tab.h"
 #include "fma-ischemes-tab.h"
@@ -190,7 +190,7 @@ fma_icommand_tab_init( FMAICommandTab *instance )
                        thisfn,
                        ( void * ) instance, G_OBJECT_TYPE_NAME( instance ));
 
-       nact_main_tab_init( NACT_MAIN_WINDOW( instance ), TAB_COMMAND );
+       fma_main_tab_init( NACT_MAIN_WINDOW( instance ), TAB_COMMAND );
        data = get_icommand_data( instance );
        data->on_selection_change = FALSE;
        data->tokens = NULL;
@@ -333,7 +333,7 @@ on_tree_selection_changed( NactTreeView *tview, GList *selected_items, FMAIComma
                        thisfn, ( void * ) profile, G_OBJECT_TYPE_NAME( profile ));
 
        enable_tab = ( profile != NULL );
-       nact_main_tab_enable_page( NACT_MAIN_WINDOW( instance ), TAB_COMMAND, enable_tab );
+       fma_main_tab_enable_page( NACT_MAIN_WINDOW( instance ), TAB_COMMAND, enable_tab );
 
        data = get_icommand_data( instance );
        data->on_selection_change = TRUE;
diff --git a/src/ui/fma-ienvironment-tab.c b/src/ui/fma-ienvironment-tab.c
index 26b7d71..0bfbe1c 100644
--- a/src/ui/fma-ienvironment-tab.c
+++ b/src/ui/fma-ienvironment-tab.c
@@ -44,7 +44,7 @@
 #include "core/fma-settings.h"
 
 #include "base-gtk-utils.h"
-#include "nact-main-tab.h"
+#include "fma-main-tab.h"
 #include "nact-main-window.h"
 #include "fma-ienvironment-tab.h"
 
@@ -214,7 +214,7 @@ fma_ienvironment_tab_init( FMAIEnvironmentTab *instance )
                        thisfn,
                        ( void * ) instance, G_OBJECT_TYPE_NAME( instance ));
 
-       nact_main_tab_init( NACT_MAIN_WINDOW( instance ), TAB_ENVIRONMENT );
+       fma_main_tab_init( NACT_MAIN_WINDOW( instance ), TAB_ENVIRONMENT );
        initialize_gtk( instance );
        initialize_window( instance );
 
@@ -375,7 +375,7 @@ on_tree_selection_changed( NactTreeView *tview, GList *selected_items, FMAIEnvir
                        NULL );
 
        enable_tab = ( context != NULL );
-       nact_main_tab_enable_page( NACT_MAIN_WINDOW( instance ), TAB_ENVIRONMENT, enable_tab );
+       fma_main_tab_enable_page( NACT_MAIN_WINDOW( instance ), TAB_ENVIRONMENT, enable_tab );
 
        data = get_ienviron_data( instance );
        data->on_selection_change = TRUE;
diff --git a/src/ui/fma-iexecution-tab.c b/src/ui/fma-iexecution-tab.c
index 11cb3cd..b4d8fd5 100644
--- a/src/ui/fma-iexecution-tab.c
+++ b/src/ui/fma-iexecution-tab.c
@@ -38,7 +38,7 @@
 #include "core/fma-gtk-utils.h"
 
 #include "base-gtk-utils.h"
-#include "nact-main-tab.h"
+#include "fma-main-tab.h"
 #include "nact-main-window.h"
 #include "fma-iexecution-tab.h"
 
@@ -163,7 +163,7 @@ fma_iexecution_tab_init( FMAIExecutionTab *instance )
                        thisfn,
                        ( void * ) instance, G_OBJECT_TYPE_NAME( instance ));
 
-       nact_main_tab_init( NACT_MAIN_WINDOW( instance ), TAB_EXECUTION );
+       fma_main_tab_init( NACT_MAIN_WINDOW( instance ), TAB_EXECUTION );
        initialize_window( instance );
 
        data = get_iexecution_data( instance );
@@ -254,7 +254,7 @@ on_tree_selection_changed( NactTreeView *tview, GList *selected_items, FMAIExecu
                        NULL );
 
        enable_tab = ( profile != NULL );
-       nact_main_tab_enable_page( NACT_MAIN_WINDOW( instance ), TAB_EXECUTION, enable_tab );
+       fma_main_tab_enable_page( NACT_MAIN_WINDOW( instance ), TAB_EXECUTION, enable_tab );
 
        data = get_iexecution_data( instance );
        data->on_selection_change = TRUE;
diff --git a/src/ui/fma-ifolders-tab.c b/src/ui/fma-ifolders-tab.c
index 494d066..2bae7dc 100644
--- a/src/ui/fma-ifolders-tab.c
+++ b/src/ui/fma-ifolders-tab.c
@@ -41,7 +41,7 @@
 
 #include "base-gtk-utils.h"
 #include "fma-application.h"
-#include "nact-main-tab.h"
+#include "fma-main-tab.h"
 #include "nact-main-window.h"
 #include "nact-match-list.h"
 #include "fma-ifolders-tab.h"
@@ -156,7 +156,7 @@ fma_ifolders_tab_init( FMAIFoldersTab *instance )
                        thisfn,
                        ( void * ) instance, G_OBJECT_TYPE_NAME( instance ));
 
-       nact_main_tab_init( NACT_MAIN_WINDOW( instance ), TAB_FOLDERS );
+       fma_main_tab_init( NACT_MAIN_WINDOW( instance ), TAB_FOLDERS );
        initialize_gtk( instance );
        initialize_window( instance );
 
@@ -224,7 +224,7 @@ on_tree_selection_changed( NactTreeView *tview, GList *selected_items, FMAIFolde
                        NULL );
 
        enable_tab = ( context != NULL );
-       nact_main_tab_enable_page( NACT_MAIN_WINDOW( instance ), TAB_FOLDERS, enable_tab );
+       fma_main_tab_enable_page( NACT_MAIN_WINDOW( instance ), TAB_FOLDERS, enable_tab );
 
        button = fma_gtk_utils_find_widget_by_name( GTK_CONTAINER( instance ), "FolderBrowseButton" );
        base_gtk_utils_set_editable( G_OBJECT( button ), editable );
diff --git a/src/ui/fma-imimetypes-tab.c b/src/ui/fma-imimetypes-tab.c
index 050c9b3..1f6ee75 100644
--- a/src/ui/fma-imimetypes-tab.c
+++ b/src/ui/fma-imimetypes-tab.c
@@ -37,7 +37,7 @@
 
 #include "core/fma-gtk-utils.h"
 
-#include "nact-main-tab.h"
+#include "fma-main-tab.h"
 #include "nact-main-window.h"
 #include "nact-match-list.h"
 #include "fma-imimetypes-tab.h"
@@ -151,7 +151,7 @@ fma_imimetypes_tab_init( FMAIMimetypesTab *instance )
                        thisfn,
                        ( void * ) instance, G_OBJECT_TYPE_NAME( instance ));
 
-       nact_main_tab_init( NACT_MAIN_WINDOW( instance ), TAB_MIMETYPES );
+       fma_main_tab_init( NACT_MAIN_WINDOW( instance ), TAB_MIMETYPES );
        initialize_gtk( instance );
        initialize_window( instance );
 
@@ -227,7 +227,7 @@ on_tree_selection_changed( NactTreeView *tview, GList *selected_items, FMAIMimet
                        NULL );
 
        enable_tab = ( context != NULL );
-       nact_main_tab_enable_page( NACT_MAIN_WINDOW( instance ), TAB_MIMETYPES, enable_tab );
+       fma_main_tab_enable_page( NACT_MAIN_WINDOW( instance ), TAB_MIMETYPES, enable_tab );
 }
 
 static GSList *
diff --git a/src/ui/fma-iproperties-tab.c b/src/ui/fma-iproperties-tab.c
index 7e0635e..ee8db02 100644
--- a/src/ui/fma-iproperties-tab.c
+++ b/src/ui/fma-iproperties-tab.c
@@ -42,7 +42,7 @@
 
 #include "base-gtk-utils.h"
 #include "fma-iproperties-tab.h"
-#include "nact-main-tab.h"
+#include "fma-main-tab.h"
 #include "nact-main-window.h"
 
 /* private interface data
@@ -168,7 +168,7 @@ fma_iproperties_tab_init( FMAIPropertiesTab *instance )
                        thisfn,
                        ( void * ) instance, G_OBJECT_TYPE_NAME( instance ));
 
-       nact_main_tab_init( NACT_MAIN_WINDOW( instance ), TAB_PROPERTIES );
+       fma_main_tab_init( NACT_MAIN_WINDOW( instance ), TAB_PROPERTIES );
        initialize_window( instance );
 
        data = get_iproperties_data( instance );
@@ -252,7 +252,7 @@ on_tree_selection_changed( NactTreeView *tview, GList *selected_items, FMAIPrope
        g_return_if_fail( !item || FMA_IS_OBJECT_ITEM( item ));
 
        enable_tab = ( count_selected == 1 );
-       nact_main_tab_enable_page( NACT_MAIN_WINDOW( instance ), TAB_PROPERTIES, enable_tab );
+       fma_main_tab_enable_page( NACT_MAIN_WINDOW( instance ), TAB_PROPERTIES, enable_tab );
 
        data = get_iproperties_data( instance );
        data->on_selection_change = TRUE;
diff --git a/src/ui/fma-ischemes-tab.c b/src/ui/fma-ischemes-tab.c
index d1fd70f..e94c2bc 100644
--- a/src/ui/fma-ischemes-tab.c
+++ b/src/ui/fma-ischemes-tab.c
@@ -39,7 +39,7 @@
 #include "core/fma-gtk-utils.h"
 
 #include "base-gtk-utils.h"
-#include "nact-main-tab.h"
+#include "fma-main-tab.h"
 #include "nact-main-window.h"
 #include "nact-match-list.h"
 #include "fma-add-scheme-dialog.h"
@@ -155,7 +155,7 @@ fma_ischemes_tab_init( FMAISchemesTab *instance )
                        thisfn,
                        ( void * ) instance, G_OBJECT_TYPE_NAME( instance ));
 
-       nact_main_tab_init( NACT_MAIN_WINDOW( instance ), TAB_SCHEMES );
+       fma_main_tab_init( NACT_MAIN_WINDOW( instance ), TAB_SCHEMES );
        initialize_gtk( instance );
        initialize_window( instance );
 
@@ -223,7 +223,7 @@ on_tree_selection_changed( NactTreeView *tview, GList *selected_items, FMAISchem
                        NULL );
 
        enable_tab = ( context != NULL );
-       nact_main_tab_enable_page( NACT_MAIN_WINDOW( instance ), TAB_SCHEMES, enable_tab );
+       fma_main_tab_enable_page( NACT_MAIN_WINDOW( instance ), TAB_SCHEMES, enable_tab );
 
        button = fma_gtk_utils_find_widget_by_name( GTK_CONTAINER( instance ), "AddFromDefaultButton" );
        base_gtk_utils_set_editable( G_OBJECT( button ), editable );
diff --git a/src/ui/nact-main-tab.h b/src/ui/fma-main-tab.h
similarity index 79%
rename from src/ui/nact-main-tab.h
rename to src/ui/fma-main-tab.h
index 8591728..7d48766 100644
--- a/src/ui/nact-main-tab.h
+++ b/src/ui/fma-main-tab.h
@@ -27,17 +27,17 @@
  *   ... and many others (see AUTHORS)
  */
 
-#ifndef __UI_NACT_MAIN_TAB_H__
-#define __UI_NACT_MAIN_TAB_H__
+#ifndef __UI_FMA_MAIN_TAB_H__
+#define __UI_FMA_MAIN_TAB_H__
 
 #include <api/fma-icontext.h>
 
 #include "nact-main-window-def.h"
 
 /**
- * SECTION: nact_main_tab
+ * SECTION: fma_main_tab
  * @short_description: Signals and properties.
- * @include: ui/nact-main-tab.h
+ * @include: ui/fma-main-tab.h
  *
  * Here as defined signals and properties common to all tabs.
  */
@@ -57,10 +57,10 @@ enum {
        TAB_PROPERTIES
 };
 
-void     nact_main_tab_init           ( NactMainWindow *window, gint page );
-void     nact_main_tab_enable_page    ( NactMainWindow *window, gint page, gboolean enabled );
-gboolean nact_main_tab_is_page_enabled( NactMainWindow *window, gint page );
+void     fma_main_tab_init           ( NactMainWindow *window, gint page );
+void     fma_main_tab_enable_page    ( NactMainWindow *window, gint page, gboolean enabled );
+gboolean fma_main_tab_is_page_enabled( NactMainWindow *window, gint page );
 
 G_END_DECLS
 
-#endif /* __UI_NACT_MAIN_TAB_H__ */
+#endif /* __UI_FMA_MAIN_TAB_H__ */
diff --git a/src/ui/nact-main-window.c b/src/ui/nact-main-window.c
index d124226..885c4d2 100644
--- a/src/ui/nact-main-window.c
+++ b/src/ui/nact-main-window.c
@@ -52,7 +52,7 @@
 #include "fma-ienvironment-tab.h"
 #include "fma-iexecution-tab.h"
 #include "fma-iproperties-tab.h"
-#include "nact-main-tab.h"
+#include "fma-main-tab.h"
 #include "nact-main-window.h"
 #include "nact-menu.h"
 #include "nact-statusbar.h"
diff --git a/src/ui/nact-match-list.c b/src/ui/nact-match-list.c
index 55ad627..36949da 100644
--- a/src/ui/nact-match-list.c
+++ b/src/ui/nact-match-list.c
@@ -39,7 +39,7 @@
 
 #include "base-keysyms.h"
 #include "base-gtk-utils.h"
-#include "nact-main-tab.h"
+#include "fma-main-tab.h"
 #include "nact-main-window.h"
 #include "nact-match-list.h"
 
@@ -343,7 +343,7 @@ on_tree_selection_changed( NactTreeView *treeview, GList *selected_items, MatchL
                        NULL );
 
        enable_tab = ( context != NULL );
-       nact_main_tab_enable_page( data->window, data->tab_id, enable_tab );
+       fma_main_tab_enable_page( data->window, data->tab_id, enable_tab );
 
        data->on_selection_change = TRUE;
 
diff --git a/src/ui/nact-menu-edit.c b/src/ui/nact-menu-edit.c
index 7db014e..89f3cfb 100644
--- a/src/ui/nact-menu-edit.c
+++ b/src/ui/nact-menu-edit.c
@@ -39,7 +39,7 @@
 
 #include "fma-application.h"
 #include "fma-clipboard.h"
-#include "nact-main-tab.h"
+#include "fma-main-tab.h"
 #include "nact-main-window.h"
 #include "nact-menu.h"
 #include "nact-menu-edit.h"
diff --git a/src/ui/nact-menu-file.c b/src/ui/nact-menu-file.c
index 917fec0..ac270fb 100644
--- a/src/ui/nact-menu-file.c
+++ b/src/ui/nact-menu-file.c
@@ -42,7 +42,7 @@
 
 #include "fma-application.h"
 #include "nact-statusbar.h"
-#include "nact-main-tab.h"
+#include "fma-main-tab.h"
 #include "nact-main-window.h"
 #include "nact-menu.h"
 #include "nact-menu-file.h"
diff --git a/src/ui/nact-schemes-list.c b/src/ui/nact-schemes-list.c
index 385def9..57ba3d4 100644
--- a/src/ui/nact-schemes-list.c
+++ b/src/ui/nact-schemes-list.c
@@ -39,7 +39,7 @@
 #include "base-keysyms.h"
 #include "fma-application.h"
 #include "base-gtk-utils.h"
-#include "nact-main-tab.h"
+#include "fma-main-tab.h"
 #include "nact-schemes-list.h"
 
 /* data attached to the treeview widget on initial load
diff --git a/src/ui/nact-tree-model.c b/src/ui/nact-tree-model.c
index 7616016..e2bfcbf 100644
--- a/src/ui/nact-tree-model.c
+++ b/src/ui/nact-tree-model.c
@@ -41,7 +41,7 @@
 #include "fma-application.h"
 #include "fma-clipboard.h"
 #include "base-gtk-utils.h"
-#include "nact-main-tab.h"
+#include "fma-main-tab.h"
 #include "nact-main-window.h"
 #include "nact-tree-model.h"
 #include "nact-tree-model-priv.h"


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/ui/nact-main-tab.c b/src/ui/fma-main-tab.c
similarity index 86%
rename from src/ui/nact-main-tab.c
rename to src/ui/fma-main-tab.c
index 9925462..2da8945 100644
--- a/src/ui/nact-main-tab.c
+++ b/src/ui/fma-main-tab.c
@@ -35,19 +35,19 @@
 
 #include "core/fma-gtk-utils.h"
 
-#include "nact-main-tab.h"
+#include "fma-main-tab.h"
 #include "nact-main-window.h"
 
 /**
- * nact_main_tab_init:
+ * fma_main_tab_init:
  * @window: the #NactMainWindow.
  * @num_page: the page number, starting from zero.
  *
  * Common initialization of each page of the notebook.
  * (provided that the page has itself called nact_main_tab_init())
  */
 void
-nact_main_tab_init( NactMainWindow *main_window, gint num_page )
+fma_main_tab_init( NactMainWindow *main_window, gint num_page )
 {
        GtkWidget *notebook;
        GtkWidget *page;
@@ -65,7 +65,7 @@ nact_main_tab_init( NactMainWindow *main_window, gint num_page )
 }
 
 /**
- * nact_main_tab_enable_page:
+ * fma_main_tab_enable_page:
  * @window: the #NactMainWindow.
  * @num_page: the page number, starting from zero.
  * @enabled: whether the tab should be set sensitive or not.
@@ -73,7 +73,7 @@ nact_main_tab_init( NactMainWindow *main_window, gint num_page )
  * Set the sensitivity of the tab.
  */
 void
-nact_main_tab_enable_page( NactMainWindow *window, gint num_page, gboolean enabled )
+fma_main_tab_enable_page( NactMainWindow *window, gint num_page, gboolean enabled )
 {
        GtkWidget *notebook;
        GtkWidget *page, *label;
@@ -88,14 +88,14 @@ nact_main_tab_enable_page( NactMainWindow *window, gint num_page, gboolean enabl
 }
 
 /**
- * nact_main_tab_is_page_enabled:
+ * fma_main_tab_is_page_enabled:
  * @window: the #NactMainWindow.
  * @num_page: the page number, starting from zero.
  *
  * Returns: %TRUE if the tab is sensitive, %FALSE else.
  */
 gboolean
-nact_main_tab_is_page_enabled( NactMainWindow *window, gint num_page )
+fma_main_tab_is_page_enabled( NactMainWindow *window, gint num_page )
 {
        gboolean is_sensitive;
        GtkWidget *notebook, *page;
@@ -105,7 +105,7 @@ nact_main_tab_is_page_enabled( NactMainWindow *window, gint num_page )
        page = gtk_notebook_get_nth_page( GTK_NOTEBOOK( notebook ), num_page );
        is_sensitive = gtk_widget_is_sensitive( page );
 
-       g_debug( "nact_main_tab_is_page_enabled: num_page=%d, is_sensitive=%s", num_page, is_sensitive ? 
"True":"False" );
+       g_debug( "fma_main_tab_is_page_enabled: num_page=%d, is_sensitive=%s", num_page, is_sensitive ? 
"True":"False" );
 
        return( is_sensitive );
@@ -35,19 +35,19 @@
  *
  * Common initialization of each page of the notebook.
- * (provided that the page has itself called nact_main_tab_init())
+ * (provided that the page has itself called fma_main_tab_init())
  */
 void
 }